fn entry_name(file: &ExerciseAnswerFile) -> StringExpand description
<user_id>/<submission_id>/<order_number><ext>, so that the two things a teacher needs to
identify an answer come from host-owned data only.
fn entry_name(file: &ExerciseAnswerFile) -> String<user_id>/<submission_id>/<order_number><ext>, so that the two things a teacher needs to
identify an answer come from host-owned data only.