extension_for_mime

Function extension_for_mime 

fn extension_for_mime(mime: &str) -> Option<&'static str>
The extension to give an archive entry, without the leading dot. None for a mime type we have no confident extension for, including application/octet-stream.